THE BOOST MPL LIBRARY: Tag Dispatching Protocol

Front Page / Changelog & History / Changes in Boost 1.32.0 Release / Tag Dispatching Protocol

# Tag Dispatching Protocol

The mechanism used to select algorithm implementations based on sequence family has been changed to use metafunction classes:

Before | Now
--- | ---
name`_traits<Tag>::algorithm<...>::type` | name`_impl<Tag>::apply<...>::type`

If your code implemented a custom sequence, it needs to be adjusted according to the above table; for example:

Before | Now
--- | ---
    template<> struct begin_traits<my_tag>
    {
        template< typename S > struct algorithm
        {
            typedef ... type;
        };
    };
    template<> struct begin_impl<my_tag>
    {
        template< typename S > struct apply
        {
            typedef ... type;
        };
    };